@@ -1,7 +1,7 @@
 package Perinci::CmdLine::POD;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2017-01-14'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -206,7 +206,7 @@ sub gen_pod_for_pericmd_script {
     my ($cli, $dump_res);
     if (defined $args{script}) {
         require Perinci::CmdLine::Dump;
-        my $dump_res = Perinci::CmdLine::Dump::dump_pericmd_script(
+        $dump_res = Perinci::CmdLine::Dump::dump_pericmd_script(
             filename => $args{script},
         );
         return $dump_res unless $dump_res->[0] == 200;
@@ -247,13 +247,12 @@ sub gen_pod_for_pericmd_script {
 
         my $url = $cli->{url};
         $urls{''} = $url;
-        unless ($metas{''}) {
-            my $res = $pa->request(meta => $url);
-            die "Can't meta $url: $res->[0] - $res->[1]"
-                unless $res->[0] == 200;
-            $metas{''} = $res->[2];
-        }
-        my $res = Perinci::Sub::To::CLIDocData::gen_cli_doc_data_from_meta(
+        my $res = $pa->request(meta => $url);
+        die "Can't meta $url: $res->[0] - $res->[1]"
+            unless $res->[0] == 200;
+        $metas{''} = $res->[2];
+
+        $res = Perinci::Sub::To::CLIDocData::gen_cli_doc_data_from_meta(
             meta => $metas{''},
             meta_is_normalized => 0, # because riap client is specifically set not to normalize
             common_opts  => $cli->{common_opts},
@@ -705,7 +704,7 @@ _
                     my $p = "$config_dir/$cfn->{filename}";
                     push @files, $p;
                     push @files_sectpod, $cfn->{section} // '';
-                    push @files_sectpod, "$p\n\n";
+                    push @files_sectpod, "F<$p>\n\n";
                 }
             }
         }
@@ -877,7 +876,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.005 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-01-13.
+This document describes version 0.006 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-01-14.
 
 =head1 SYNOPSIS
 
